@@ -1,6 +1,7 @@
 import json
 import logging
 import os
+from datetime import datetime, timezone
 from importlib import resources
 
 import fastjsonschema
@@ -33,7 +34,7 @@ class EventUtil:
         event = MetadataChangeEvent()
         event.tenant = EventUtil.kinesis_tenant
         event.event_header = EventHeader()
-        # event.event_header.time = datetime.now()  TODO: fix json validation on datetime [ch880]
+        event.event_header.time = datetime.now(timezone.utc)
         return event
 
     @staticmethod
