@@ -10,13 +10,13 @@
 #
 #     result = metadata_change_event_from_dict(json.loads(json_string))
 
-from dataclasses import dataclass
-from datetime import datetime
 from enum import Enum
-from typing import Any, Callable, List, Optional, Type, TypeVar, cast
-
+from dataclasses import dataclass
+from typing import Optional, Any, List, TypeVar, Type, Callable, cast
+from datetime import datetime
 import dateutil.parser
 
+
 T = TypeVar("T")
 EnumT = TypeVar("EnumT", bound=Enum)
 
@@ -84,10 +84,12 @@ class AspectType(Enum):
     DATASET_STATISTICS = "DATASET_STATISTICS"
     DATASET_UPSTREAM = "DATASET_UPSTREAM"
     GROUP_INFO = "GROUP_INFO"
+    KNOWLEDGE_CARD_INFO = "KNOWLEDGE_CARD_INFO"
     OWNERSHIP = "OWNERSHIP"
     PERSON_EDITABLE_INFO = "PERSON_EDITABLE_INFO"
     PERSON_ORGANIZATION = "PERSON_ORGANIZATION"
     PERSON_PROPERTIES = "PERSON_PROPERTIES"
+    PERSON_SLACK_PROFILE = "PERSON_SLACK_PROFILE"
     PROPERTIES = "PROPERTIES"
 
 
@@ -197,6 +199,7 @@ class EntityType(Enum):
     DASHBOARD = "DASHBOARD"
     DATASET = "DATASET"
     GROUP = "GROUP"
+    KNOWLEDGE_CARD = "KNOWLEDGE_CARD"
     PERSON = "PERSON"
     PROJECT = "PROJECT"
 
@@ -308,11 +311,15 @@ class DashboardUpstream:
 
 @dataclass
 class Dashboard:
+    """Backing store for an optionally provided creation date"""
     created_at: Optional[datetime] = None
+    """A class representation of the BSON ObjectId type."""
+    id: Optional[ObjectID] = None
+    dashboard_created_at: Optional[datetime] = None
     dashboard_info: Optional[DashboardInfo] = None
     deleted_at: Optional[datetime] = None
     entity_type: Optional[EntityType] = None
-    id: Optional[str] = None
+    dashboard_id: Optional[str] = None
     last_modified_at: Optional[datetime] = None
     """Identify an entity "logically", besides the system generated UUID.
     Each entity must have a logicalId to be ingested.
@@ -327,23 +334,27 @@ class Dashboard:
     @staticmethod
     def from_dict(obj: Any) -> 'Dashboard':
         assert isinstance(obj, dict)
-        created_at = from_union([from_datetime, from_none], obj.get("createdAt"))
+        created_at = from_union([from_datetime, from_none], obj.get("_createdAt"))
+        id = from_union([ObjectID.from_dict, from_none], obj.get("_id"))
+        dashboard_created_at = from_union([from_datetime, from_none], obj.get("createdAt"))
         dashboard_info = from_union([DashboardInfo.from_dict, from_none], obj.get("dashboardInfo"))
         deleted_at = from_union([from_datetime, from_none], obj.get("deletedAt"))
         entity_type = from_union([EntityType, from_none], obj.get("entityType"))
-        id = from_union([from_str, from_none], obj.get("id"))
+        dashboard_id = from_union([from_str, from_none], obj.get("id"))
         last_modified_at = from_union([from_datetime, from_none], obj.get("lastModifiedAt"))
         logical_id = from_union([DashboardLogicalID.from_dict, from_none], obj.get("logicalId"))
         upstream = from_union([DashboardUpstream.from_dict, from_none], obj.get("upstream"))
-        return Dashboard(created_at, dashboard_info, deleted_at, entity_type, id, last_modified_at, logical_id, upstream)
+        return Dashboard(created_at, id, dashboard_created_at, dashboard_info, deleted_at, entity_type, dashboard_id, last_modified_at, logical_id, upstream)
 
     def to_dict(self) -> dict:
         result: dict = {}
-        result["createdAt"] = from_union([lambda x: x.isoformat(), from_none], self.created_at)
+        result["_createdAt"] = from_union([lambda x: x.isoformat(), from_none], self.created_at)
+        result["_id"] = from_union([lambda x: to_class(ObjectID, x), from_none], self.id)
+        result["createdAt"] = from_union([lambda x: x.isoformat(), from_none], self.dashboard_created_at)
         result["dashboardInfo"] = from_union([lambda x: to_class(DashboardInfo, x), from_none], self.dashboard_info)
         result["deletedAt"] = from_union([lambda x: x.isoformat(), from_none], self.deleted_at)
         result["entityType"] = from_union([lambda x: to_enum(EntityType, x), from_none], self.entity_type)
-        result["id"] = from_union([from_str, from_none], self.id)
+        result["id"] = from_union([from_str, from_none], self.dashboard_id)
         result["lastModifiedAt"] = from_union([lambda x: x.isoformat(), from_none], self.last_modified_at)
         result["logicalId"] = from_union([lambda x: to_class(DashboardLogicalID, x), from_none], self.logical_id)
         result["upstream"] = from_union([lambda x: to_class(DashboardUpstream, x), from_none], self.upstream)
@@ -954,14 +965,18 @@ class DatasetUpstream:
 
 @dataclass
 class Dataset:
-    comments: Optional[List[DatasetComment]] = None
+    """Backing store for an optionally provided creation date"""
     created_at: Optional[datetime] = None
+    """A class representation of the BSON ObjectId type."""
+    id: Optional[ObjectID] = None
+    comments: Optional[List[DatasetComment]] = None
+    dataset_created_at: Optional[datetime] = None
     deleted_at: Optional[datetime] = None
     documentation: Optional[DatasetDocumentation] = None
     """DatasetDownstream captures downstream lineages from this dataset"""
     downstream: Optional[DatasetDownstream] = None
     entity_type: Optional[EntityType] = None
-    id: Optional[str] = None
+    dataset_id: Optional[str] = None
     last_modified_at: Optional[datetime] = None
     """Identify an entity "logically", besides the system generated UUID.
     Each entity must have a logicalId to be ingested.
@@ -983,13 +998,15 @@ class Dataset:
     @staticmethod
     def from_dict(obj: Any) -> 'Dataset':
         assert isinstance(obj, dict)
+        created_at = from_union([from_datetime, from_none], obj.get("_createdAt"))
+        id = from_union([ObjectID.from_dict, from_none], obj.get("_id"))
         comments = from_union([lambda x: from_list(DatasetComment.from_dict, x), from_none], obj.get("comments"))
-        created_at = from_union([from_datetime, from_none], obj.get("createdAt"))
+        dataset_created_at = from_union([from_datetime, from_none], obj.get("createdAt"))
         deleted_at = from_union([from_datetime, from_none], obj.get("deletedAt"))
         documentation = from_union([DatasetDocumentation.from_dict, from_none], obj.get("documentation"))
         downstream = from_union([DatasetDownstream.from_dict, from_none], obj.get("downstream"))
         entity_type = from_union([EntityType, from_none], obj.get("entityType"))
-        id = from_union([from_str, from_none], obj.get("id"))
+        dataset_id = from_union([from_str, from_none], obj.get("id"))
         last_modified_at = from_union([from_datetime, from_none], obj.get("lastModifiedAt"))
         logical_id = from_union([DatasetLogicalID.from_dict, from_none], obj.get("logicalId"))
         ownership = from_union([Ownership.from_dict, from_none], obj.get("ownership"))
@@ -997,17 +1014,19 @@ class Dataset:
         schema = from_union([DatasetSchema.from_dict, from_none], obj.get("schema"))
         statistics = from_union([DatasetStatistics.from_dict, from_none], obj.get("statistics"))
         upstream = from_union([DatasetUpstream.from_dict, from_none], obj.get("upstream"))
-        return Dataset(comments, created_at, deleted_at, documentation, downstream, entity_type, id, last_modified_at, logical_id, ownership, properties, schema, statistics, upstream)
+        return Dataset(created_at, id, comments, dataset_created_at, deleted_at, documentation, downstream, entity_type, dataset_id, last_modified_at, logical_id, ownership, properties, schema, statistics, upstream)
 
     def to_dict(self) -> dict:
         result: dict = {}
+        result["_createdAt"] = from_union([lambda x: x.isoformat(), from_none], self.created_at)
+        result["_id"] = from_union([lambda x: to_class(ObjectID, x), from_none], self.id)
         result["comments"] = from_union([lambda x: from_list(lambda x: to_class(DatasetComment, x), x), from_none], self.comments)
-        result["createdAt"] = from_union([lambda x: x.isoformat(), from_none], self.created_at)
+        result["createdAt"] = from_union([lambda x: x.isoformat(), from_none], self.dataset_created_at)
         result["deletedAt"] = from_union([lambda x: x.isoformat(), from_none], self.deleted_at)
         result["documentation"] = from_union([lambda x: to_class(DatasetDocumentation, x), from_none], self.documentation)
         result["downstream"] = from_union([lambda x: to_class(DatasetDownstream, x), from_none], self.downstream)
         result["entityType"] = from_union([lambda x: to_enum(EntityType, x), from_none], self.entity_type)
-        result["id"] = from_union([from_str, from_none], self.id)
+        result["id"] = from_union([from_str, from_none], self.dataset_id)
         result["lastModifiedAt"] = from_union([lambda x: x.isoformat(), from_none], self.last_modified_at)
         result["logicalId"] = from_union([lambda x: to_class(DatasetLogicalID, x), from_none], self.logical_id)
         result["ownership"] = from_union([lambda x: to_class(Ownership, x), from_none], self.ownership)
@@ -1085,11 +1104,15 @@ class GroupInfo:
 
 @dataclass
 class Group:
+    """Backing store for an optionally provided creation date"""
     created_at: Optional[datetime] = None
+    """A class representation of the BSON ObjectId type."""
+    id: Optional[ObjectID] = None
+    group_created_at: Optional[datetime] = None
     deleted_at: Optional[datetime] = None
     entity_type: Optional[EntityType] = None
     group_info: Optional[GroupInfo] = None
-    id: Optional[str] = None
+    group_id: Optional[str] = None
     last_modified_at: Optional[datetime] = None
     """Identify an entity "logically", besides the system generated UUID.
     Each entity must have a logicalId to be ingested.
@@ -1102,22 +1125,26 @@ class Group:
     @staticmethod
     def from_dict(obj: Any) -> 'Group':
         assert isinstance(obj, dict)
-        created_at = from_union([from_datetime, from_none], obj.get("createdAt"))
+        created_at = from_union([from_datetime, from_none], obj.get("_createdAt"))
+        id = from_union([ObjectID.from_dict, from_none], obj.get("_id"))
+        group_created_at = from_union([from_datetime, from_none], obj.get("createdAt"))
         deleted_at = from_union([from_datetime, from_none], obj.get("deletedAt"))
         entity_type = from_union([EntityType, from_none], obj.get("entityType"))
         group_info = from_union([GroupInfo.from_dict, from_none], obj.get("groupInfo"))
-        id = from_union([from_str, from_none], obj.get("id"))
+        group_id = from_union([from_str, from_none], obj.get("id"))
         last_modified_at = from_union([from_datetime, from_none], obj.get("lastModifiedAt"))
         logical_id = from_union([GroupID.from_dict, from_none], obj.get("logicalId"))
-        return Group(created_at, deleted_at, entity_type, group_info, id, last_modified_at, logical_id)
+        return Group(created_at, id, group_created_at, deleted_at, entity_type, group_info, group_id, last_modified_at, logical_id)
 
     def to_dict(self) -> dict:
         result: dict = {}
-        result["createdAt"] = from_union([lambda x: x.isoformat(), from_none], self.created_at)
+        result["_createdAt"] = from_union([lambda x: x.isoformat(), from_none], self.created_at)
+        result["_id"] = from_union([lambda x: to_class(ObjectID, x), from_none], self.id)
+        result["createdAt"] = from_union([lambda x: x.isoformat(), from_none], self.group_created_at)
         result["deletedAt"] = from_union([lambda x: x.isoformat(), from_none], self.deleted_at)
         result["entityType"] = from_union([lambda x: to_enum(EntityType, x), from_none], self.entity_type)
         result["groupInfo"] = from_union([lambda x: to_class(GroupInfo, x), from_none], self.group_info)
-        result["id"] = from_union([from_str, from_none], self.id)
+        result["id"] = from_union([from_str, from_none], self.group_id)
         result["lastModifiedAt"] = from_union([lambda x: x.isoformat(), from_none], self.last_modified_at)
         result["logicalId"] = from_union([lambda x: to_class(GroupID, x), from_none], self.logical_id)
         return result
@@ -1306,19 +1333,66 @@ class PersonProperties:
         return result
 
 
+@dataclass
+class PersonSlackProfile:
+    id: Optional[ObjectID] = None
+    aspect_type: Optional[AspectType] = None
+    created_at: Optional[datetime] = None
+    deleted: Optional[bool] = None
+    entity_id: Optional[str] = None
+    person_slack_profile_id: Optional[str] = None
+    latest: Optional[bool] = None
+    slack_id: Optional[str] = None
+    team_id: Optional[str] = None
+    username: Optional[str] = None
+
+    @staticmethod
+    def from_dict(obj: Any) -> 'PersonSlackProfile':
+        assert isinstance(obj, dict)
+        id = from_union([ObjectID.from_dict, from_none], obj.get("_id"))
+        aspect_type = from_union([AspectType, from_none], obj.get("aspectType"))
+        created_at = from_union([from_datetime, from_none], obj.get("createdAt"))
+        deleted = from_union([from_bool, from_none], obj.get("deleted"))
+        entity_id = from_union([from_str, from_none], obj.get("entityId"))
+        person_slack_profile_id = from_union([from_str, from_none], obj.get("id"))
+        latest = from_union([from_bool, from_none], obj.get("latest"))
+        slack_id = from_union([from_str, from_none], obj.get("slackId"))
+        team_id = from_union([from_str, from_none], obj.get("teamId"))
+        username = from_union([from_str, from_none], obj.get("username"))
+        return PersonSlackProfile(id, aspect_type, created_at, deleted, entity_id, person_slack_profile_id, latest, slack_id, team_id, username)
+
+    def to_dict(self) -> dict:
+        result: dict = {}
+        result["_id"] = from_union([lambda x: to_class(ObjectID, x), from_none], self.id)
+        result["aspectType"] = from_union([lambda x: to_enum(AspectType, x), from_none], self.aspect_type)
+        result["createdAt"] = from_union([lambda x: x.isoformat(), from_none], self.created_at)
+        result["deleted"] = from_union([from_bool, from_none], self.deleted)
+        result["entityId"] = from_union([from_str, from_none], self.entity_id)
+        result["id"] = from_union([from_str, from_none], self.person_slack_profile_id)
+        result["latest"] = from_union([from_bool, from_none], self.latest)
+        result["slackId"] = from_union([from_str, from_none], self.slack_id)
+        result["teamId"] = from_union([from_str, from_none], self.team_id)
+        result["username"] = from_union([from_str, from_none], self.username)
+        return result
+
+
 @dataclass
 class Person:
     """A person entity represents any individual who is a member of the organization (or beyond)
     and can
     potentially have some relation to the other entities in our application
     """
-    avatar_url: Optional[str] = None
+    """Backing store for an optionally provided creation date"""
     created_at: Optional[datetime] = None
+    """A class representation of the BSON ObjectId type."""
+    id: Optional[ObjectID] = None
+    avatar_url: Optional[str] = None
+    person_created_at: Optional[datetime] = None
     deleted_at: Optional[datetime] = None
     editable_info: Optional[PersonEditableInfo] = None
     entity_type: Optional[EntityType] = None
     first_name: Optional[str] = None
-    id: Optional[str] = None
+    person_id: Optional[str] = None
     last_modified_at: Optional[datetime] = None
     last_name: Optional[str] = None
     """Identify an entity "logically", besides the system generated UUID.
@@ -1331,40 +1405,47 @@ class Person:
     organization: Optional[PersonOrganization] = None
     password: Optional[str] = None
     properties: Optional[PersonProperties] = None
+    slack_profile: Optional[PersonSlackProfile] = None
 
     @staticmethod
     def from_dict(obj: Any) -> 'Person':
         assert isinstance(obj, dict)
+        created_at = from_union([from_datetime, from_none], obj.get("_createdAt"))
+        id = from_union([ObjectID.from_dict, from_none], obj.get("_id"))
         avatar_url = from_union([from_str, from_none], obj.get("avatarUrl"))
-        created_at = from_union([from_datetime, from_none], obj.get("createdAt"))
+        person_created_at = from_union([from_datetime, from_none], obj.get("createdAt"))
         deleted_at = from_union([from_datetime, from_none], obj.get("deletedAt"))
         editable_info = from_union([PersonEditableInfo.from_dict, from_none], obj.get("editableInfo"))
         entity_type = from_union([EntityType, from_none], obj.get("entityType"))
         first_name = from_union([from_str, from_none], obj.get("firstName"))
-        id = from_union([from_str, from_none], obj.get("id"))
+        person_id = from_union([from_str, from_none], obj.get("id"))
         last_modified_at = from_union([from_datetime, from_none], obj.get("lastModifiedAt"))
         last_name = from_union([from_str, from_none], obj.get("lastName"))
         logical_id = from_union([PersonID.from_dict, from_none], obj.get("logicalId"))
         organization = from_union([PersonOrganization.from_dict, from_none], obj.get("organization"))
         password = from_union([from_str, from_none], obj.get("password"))
         properties = from_union([PersonProperties.from_dict, from_none], obj.get("properties"))
-        return Person(avatar_url, created_at, deleted_at, editable_info, entity_type, first_name, id, last_modified_at, last_name, logical_id, organization, password, properties)
+        slack_profile = from_union([PersonSlackProfile.from_dict, from_none], obj.get("slackProfile"))
+        return Person(created_at, id, avatar_url, person_created_at, deleted_at, editable_info, entity_type, first_name, person_id, last_modified_at, last_name, logical_id, organization, password, properties, slack_profile)
 
     def to_dict(self) -> dict:
         result: dict = {}
+        result["_createdAt"] = from_union([lambda x: x.isoformat(), from_none], self.created_at)
+        result["_id"] = from_union([lambda x: to_class(ObjectID, x), from_none], self.id)
         result["avatarUrl"] = from_union([from_str, from_none], self.avatar_url)
-        result["createdAt"] = from_union([lambda x: x.isoformat(), from_none], self.created_at)
+        result["createdAt"] = from_union([lambda x: x.isoformat(), from_none], self.person_created_at)
         result["deletedAt"] = from_union([lambda x: x.isoformat(), from_none], self.deleted_at)
         result["editableInfo"] = from_union([lambda x: to_class(PersonEditableInfo, x), from_none], self.editable_info)
         result["entityType"] = from_union([lambda x: to_enum(EntityType, x), from_none], self.entity_type)
         result["firstName"] = from_union([from_str, from_none], self.first_name)
-        result["id"] = from_union([from_str, from_none], self.id)
+        result["id"] = from_union([from_str, from_none], self.person_id)
         result["lastModifiedAt"] = from_union([lambda x: x.isoformat(), from_none], self.last_modified_at)
         result["lastName"] = from_union([from_str, from_none], self.last_name)
         result["logicalId"] = from_union([lambda x: to_class(PersonID, x), from_none], self.logical_id)
         result["organization"] = from_union([lambda x: to_class(PersonOrganization, x), from_none], self.organization)
         result["password"] = from_union([from_str, from_none], self.password)
         result["properties"] = from_union([lambda x: to_class(PersonProperties, x), from_none], self.properties)
+        result["slackProfile"] = from_union([lambda x: to_class(PersonSlackProfile, x), from_none], self.slack_profile)
         return result
 
 
