@@ -3,15 +3,20 @@ import os
 from dataclasses import dataclass
 from typing import Dict, Iterable, List, Sequence, Set, Tuple
 
-import looker_sdk
-from looker_sdk.sdk.api31.methods import Looker31SDK
-from looker_sdk.sdk.api31.models import DashboardElement
+try:
+    import looker_sdk
+    from looker_sdk.sdk.api31.methods import Looker31SDK
+    from looker_sdk.sdk.api31.models import DashboardElement
+except ImportError:
+    print("Please install metaphor[looker] extra\n")
+    raise
 
 from metaphor.common.event_util import EventUtil
 from metaphor.common.extractor import BaseExtractor, RunConfig
 from metaphor.common.metadata_change_event import (
     AspectType,
     Chart,
+    ChartType,
     Dashboard,
     DashboardInfo,
     DashboardLogicalID,
@@ -52,6 +57,25 @@ class LookerExtractor(BaseExtractor):
         "redshift": DataPlatform.REDSHIFT,
     }
 
+    vis_type_map = {
+        "looker_area": ChartType.AREA,
+        "looker_bar": ChartType.BAR,
+        "looker_boxplot": ChartType.BOX_PLOT,
+        "looker_column": ChartType.COLUMN,
+        "looker_donut_multiples": ChartType.DONUT,
+        "looker_line": ChartType.LINE,
+        "looker_map": ChartType.MAP,
+        "looker_geo_coordinates": ChartType.MAP,
+        "looker_geo_choropleth": ChartType.MAP,
+        "looker_pie": ChartType.PIE,
+        "looker_scatter": ChartType.SCATTER,
+        "table": ChartType.TABLE,
+        "looker_grid": ChartType.TABLE,
+        "looker_single_record": ChartType.TABLE,
+        "single_value": ChartType.TEXT,
+        "text": ChartType.TEXT,
+    }
+
     def initSdk(self, config: LookerRunConfig) -> Looker31SDK:
         # Load config using environment variables instead from looker.ini file
         # See https://github.com/looker-open-source/sdk-codegen#environment-variable-configuration
@@ -149,12 +173,19 @@ class LookerExtractor(BaseExtractor):
         dataset_ids: Set[DatasetLogicalID] = set()
         charts = []
         for e in filter(lambda e: e.type == "vis", dashboard_elements):
-            charts.append(Chart(title=e.title))
 
             if e.result_maker is None:
                 logger.warn(f"Unable to find result_maker is element {e.title}")
                 continue
 
+            chart_type = None
+            if e.result_maker.vis_config is not None:
+                chart_type = self.vis_type_map.get(
+                    e.result_maker.vis_config.get("type", ""), ChartType.OTHER
+                )
+
+            charts.append(Chart(title=e.title, chart_type=chart_type))
+
             if not isinstance(e.result_maker.filterables, Iterable):
                 logger.warn(f"Unable to iterate filterables in element {e.title}")
                 continue
